# TkLineNums
 
TkLineNums is a simple line numbering widget for Tkinter. It supports ttk themes through the set_to_ttk_style method.

![img](https://github.com/Moosems/TkLineNums/raw/main/images/TkLineNumsPhoto.png)